=========
Tutorials
=========

Welcome to the QuScope tutorials! These guides will walk you through the key features and capabilities of QuScope.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started:
   
   basic_quantum_encoding
   working_with_backends
   image_preprocessing

.. toctree::
   :maxdepth: 2
   :caption: Advanced Topics:
   
   quantum_machine_learning
   eels_analysis
   custom_algorithms

.. toctree::
   :maxdepth: 2
   :caption: Real-World Applications:
   
   microscopy_workflows
   performance_optimization
   hardware_deployment

🎯 **Tutorial Overview**
=======================

**Basic Tutorials**
- :doc:`basic_quantum_encoding` - Learn the fundamentals of quantum image encoding
- :doc:`working_with_backends` - Set up and use different quantum backends  
- :doc:`image_preprocessing` - Preprocess images for quantum algorithms

**Advanced Tutorials**
- :doc:`quantum_machine_learning` - Implement QML algorithms for microscopy
- :doc:`eels_analysis` - Analyze EELS data with quantum techniques
- :doc:`custom_algorithms` - Create your own quantum microscopy algorithms

**Applications**
- :doc:`microscopy_workflows` - Complete workflows for real microscopy data
- :doc:`performance_optimization` - Optimize your quantum algorithms
- :doc:`hardware_deployment` - Deploy on real quantum hardware

📚 **Prerequisites**
===================

Before starting these tutorials, you should have:

- Basic understanding of Python programming
- Familiarity with NumPy and image processing concepts
- Basic knowledge of quantum computing (helpful but not required)
- QuScope installed (see :doc:`../installation`)

🔗 **Additional Resources**
===========================

- :doc:`../notebooks` - Interactive Jupyter notebooks
- :doc:`../api` - Complete API reference
- `Qiskit Textbook <https://qiskit.org/textbook/>`_ - Learn quantum computing fundamentals
